netapp_ontap.models.nas API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nas`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NasSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Nas object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `application_components GET POST PATCH`

    The application_components field of the nas.

  `cifs_access GET POST`

    The list of CIFS access controls. You must provide either 'user_or_group' or 'access' to enable CIFS access.

  `nfs_access GET POST`

    The list of NFS access controls. You must provide either 'host' or 'access' to enable NFS access.

  `protection_type GET POST PATCH`

    The protection_type field of the nas.